/**
 * <copyright>
 *
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * $Id$
 */

package org.eclipse.jet.internal.runtime;


import org.eclipse.emf.common.util.BasicDiagnostic;
import org.eclipse.emf.common.util.Diagnostic;
import org.eclipse.jet.taglib.TagInfo;


/**
 * Status object for JET2 templates
 *
 */
public class JET2TemplateStatus extends BasicDiagnostic implements Diagnostic
{
  public static final int TAG_EXCEPTION = 1;

  private final String templatePath;

  private final TagInfo tagInfo;

  private final String templateBundleId;

  private final Throwable exception;

  public JET2TemplateStatus(int severity, String templateBundleId, String message, String templatePath, TagInfo tagInfo, Throwable exception)
  {
    super(severity, templateBundleId, TAG_EXCEPTION, message == null ? "" : message, null); //$NON-NLS-1$
    
    

    this.templateBundleId = templateBundleId;
    this.templatePath = templatePath;
    this.tagInfo = tagInfo;
    this.exception = exception;
  }

  /**
   * @return Returns the tagInfo.
   */
  public final TagInfo getTagInfo()
  {
    return tagInfo;
  }

  /**
   * @return Returns the templateBundleId.
   */
  public final String getTemplateBundleId()
  {
    return templateBundleId;
  }

  /**
   * @return Returns the templatePath.
   */
  public final String getTemplatePath()
  {
    return templatePath;
  }

  /**
   * @return Returns the exception.
   */
  public final Throwable getException()
  {
    return exception;
  }

}
